@@ -17,6 +17,7 @@ var URL = require('url');
 var logger = require('winston');
 var async = require('async');
 var fscan = require('./../common/fscan');
+var prpl = require('prpl-server');
 
 
 var loadRouter = function (app, prefix, wd, rd, routes, callback) {
@@ -51,60 +52,60 @@ var loadRouter = function (app, prefix, wd, rd, routes, callback) {
 }
 
 module.exports = function (app) {
-    if( app.nylon.req.r){
+    if (app.nylon.req.r) {
         //var req=app.nylon.req;
-       // var r=app.nylon.req.r;
+        // var r=app.nylon.req.r;
 
         app.nylon.req.r._Term.prototype.pager = function (req) {
-            var r=req.r;
-             var limit = 50;
-             var page = 1;
-             if (req.query._limit) {
-                 limit = parseInt(req.query._limit);
-                 page = parseInt(req.query._page);
-             }
-             else if (req.body._limit) {
-                 limit = parseInt(req.body._limit);
-                 page = parseInt(req.body._page);
-             }
-             else if (req.headers._limit) {
-                 limit = parseInt(req.headers._limit);
-                 page = parseInt(req.headers._page);
-             }
-             var skip = (limit * (page - 1));
-             var rowEnd = skip + limit;
-             var rowStart = skip + 1;
-    
-             return this.do(function (data) {
-               //  var r=this;
-                 return r.branch(
-                     data.typeOf().eq('ARRAY'),
-                     {
-                         _totalCount: data.count(),
-                         _totalPage: r.ceil(data.count().div(limit)),
-                         _pageLimit: limit,
-                         _currentPage: page,
-                         _nextPage: r.branch(r.lt(data.count(), rowEnd).or(r.eq(data.count(), rowEnd)), page, page + 1),
-                         _rowStart: rowStart,
-                         _rowEnd: r.branch(r.lt(data.count(), rowEnd), data.count(), rowEnd),
-                         _option: 'pagination',
-                         data: data.skip(skip).limit(limit)
-                     }
-                     ,
-                     data
-                 )
-             })
-         };
-   
+            var r = req.r;
+            var limit = 50;
+            var page = 1;
+            if (req.query._limit) {
+                limit = parseInt(req.query._limit);
+                page = parseInt(req.query._page);
+            }
+            else if (req.body._limit) {
+                limit = parseInt(req.body._limit);
+                page = parseInt(req.body._page);
+            }
+            else if (req.headers._limit) {
+                limit = parseInt(req.headers._limit);
+                page = parseInt(req.headers._page);
+            }
+            var skip = (limit * (page - 1));
+            var rowEnd = skip + limit;
+            var rowStart = skip + 1;
+
+            return this.do(function (data) {
+                //  var r=this;
+                return r.branch(
+                    data.typeOf().eq('ARRAY'),
+                    {
+                        _totalCount: data.count(),
+                        _totalPage: r.ceil(data.count().div(limit)),
+                        _pageLimit: limit,
+                        _currentPage: page,
+                        _nextPage: r.branch(r.lt(data.count(), rowEnd).or(r.eq(data.count(), rowEnd)), page, page + 1),
+                        _rowStart: rowStart,
+                        _rowEnd: r.branch(r.lt(data.count(), rowEnd), data.count(), rowEnd),
+                        _option: 'pagination',
+                        data: data.skip(skip).limit(limit)
+                    }
+                    ,
+                    data
+                )
+            })
+        };
+
     }
-    
+
 
 
     app.use(function (req, res, next) {
         Object.assign(req, app.nylon.req);
         Object.assign(res, app.nylon.res);
 
-      
+
 
         res.header("Access-Control-Allow-Origin", "*");
         res.header("Access-Control-Allow-Methods", "GET, POST, OPTIONS, PUT, DELETE");
@@ -112,10 +113,15 @@ module.exports = function (app) {
         next();
     });
 
- 
+
     fscan.scan(app.nylon.work_dir + route_dir, ".routes.js", true, function (err, routes) {
         loadRouter(app, "/api", app.nylon.work_dir, route_dir, routes, function (err, app) {
-           
+            app.get('/*', prpl.makeHandler('./public', {
+                builds: [
+                    { name: 'modern', browserCapabilities: ['es2015', 'push'] },
+                    { name: 'fallback' },
+                ],
+            }));
         });
     });
 
